==> currents-api-types-0.0.42.tgz: package/graph/strategy/isomorphism.ts <==
import { Isomorphism } from '../../utils/types';
import { RoutingStrategy } from './types';
import { routingStrategyParser, routingStrategyThresholdQueryParamsParser } from './parsers';
import {
  ROUTING_STRATEGY_KEY_FANOUT,
  ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR,
  ROUTING_STRATEGY_SERIALIZED_SEPARATOR,
} from './constants';
import { ary1 } from '../../utils/function';
import { assertExactLength, getOnlyOne, partition } from '../../utils/array';
import assert from 'assert';
import { RoutingStrategySerialized } from './brand.types';

const KEY_KEY = 'key' as const;

export const routingStrategyIsomorphism: Isomorphism<RoutingStrategySerialized, RoutingStrategy> = {
  to: (s) => {
    const kvs = s.split(ROUTING_STRATEGY_SERIALIZED_SEPARATOR);
    assert.equal(kvs.length, new Set(kvs.map((kv) => kv[0])).size, 'panic! duplicate keys');
    const pairs = kvs
      .map((kv) => kv.split(ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR))
      .map(
        ary1(
          assertExactLength(
            2,
            `panic! Invalid routing strategy serialized: ${s}, extra "${ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR}" symbol?`
          )
        )
      );
    const [keyPairs, nonKeyPairs] = partition(pairs, ([k]) => k === KEY_KEY);
    const keyPair = getOnlyOne(keyPairs);
    return routingStrategyParser.parse({
      [keyPair[0]]: keyPair[1],
      ...(keyPair[1] === ROUTING_STRATEGY_KEY_FANOUT
        ? {}
        : { params: routingStrategyThresholdQueryParamsParser.parse(Object.fromEntries<string>(nonKeyPairs)) }),
    });
  },
  from: (r) => {
    return Object.entries({ key: r['key'], ...(r.key === ROUTING_STRATEGY_KEY_FANOUT ? {} : r.params) })
      .map(([k, v]) => `${k}${ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR}${v}`)
      .join(ROUTING_STRATEGY_SERIALIZED_SEPARATOR) as RoutingStrategySerialized;
  },
};

==> currents-api-types-0.0.70.tgz: package/graph/strategy/isomorphism.ts <==
import { Isomorphism } from '../../utils/types';
import { RoutingStrategy } from './types';
import { routingStrategyParser, routingStrategyThresholdQueryParamsParser } from './parsers';
import {
  ROUTING_STRATEGY_KEY_ACTIVATION_THRESHOLD,
  ROUTING_STRATEGY_KEY_FANOUT,
  ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR,
  ROUTING_STRATEGY_SERIALIZED_SEPARATOR,
} from './constants';
import { ary1 } from '../../utils/function';
import { assertExactLength, getOnlyOne, partition } from '../../utils/array';
import assert from 'assert';
import { RoutingStrategySerialized } from './brand.types';

const KEY_KEY = 'key' as const;

export const routingStrategyIsomorphism: Isomorphism<RoutingStrategySerialized, RoutingStrategy> = {
  to: (s) => {
    const kvs = s.split(ROUTING_STRATEGY_SERIALIZED_SEPARATOR);
    assert.equal(kvs.length, new Set(kvs.map((kv) => kv[0])).size, 'panic! duplicate keys');
    const pairs = kvs
      .map((kv) => kv.split(ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR))
      .map(
        ary1(
          assertExactLength(
            2,
            `panic! Invalid routing strategy serialized: ${s}, extra "${ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR}" symbol?`
          )
        )
      );
    const [keyPairs, nonKeyPairs] = partition(pairs, ([k]) => k === KEY_KEY);
    const keyPair = getOnlyOne(keyPairs);
    return routingStrategyParser.parse({
      [keyPair[0]]: keyPair[1],
      ...(keyPair[1] === ROUTING_STRATEGY_KEY_FANOUT
        ? {}
        : { params: routingStrategyThresholdQueryParamsParser.parse(Object.fromEntries<string>(nonKeyPairs)) }),
    });
  },
  from: (r) => {
    return Object.entries({
      key: r['key'],
      ...(r.key === ROUTING_STRATEGY_KEY_FANOUT || r.key === ROUTING_STRATEGY_KEY_ACTIVATION_THRESHOLD ? {} : r.params),
    })
      .map(([k, v]) => `${k}${ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR}${v}`)
      .join(ROUTING_STRATEGY_SERIALIZED_SEPARATOR) as RoutingStrategySerialized;
  },
};
